using System;
using System.Collections.Generic;
using System.Linq;
using MonoTouch.Dialog;
using MonoTouch.UIKit;
using System.Drawing;
using notes.Core;

using ElementPack;

namespace notes.iPhone
{
	public class MyViewController : UIViewController
	{
		private List<Note> notes;
		private DialogViewController dvcDetails;

		StringElement saveButton;
		StringElement deleteButton;
		EntryElement titleElement;
		DateTimeElement dateElement;
		SimpleMultilineEntryElement textElement;

		private UITableView table;
		NotesTableSource Source;

		public MyViewController()
		{
			this.Title = "ApplicationTitle".t();
		}

		public void SaveNote(Note note)
		{
			if (note.NoteId == 0) {
				notes.Add (note);
				if (notes.Count < 1) {
					note.NoteId = 1;
				} else {
					note.NoteId = notes [notes.Count - 2].NoteId + 1;
				}
			}
			NoteManager.SaveNote (note);
			table.ReloadData ();
		}

		public void DeleteNote(Note note)
		{
			NoteManager.DeleteNote (note.NoteId);
			notes.Remove (note);
			table.ReloadData ();
		}

		public void CreateMTD(Note note)
		{
			saveButton = new StringElement ("Save".t(), delegate {
				note.NoteTitle = titleElement.Value;
				note.NoteDate = dateElement.DateValue;
				note.NoteText = textElement.Value;

				this.SaveNote(note);

				this.NavigationController.PopToRootViewController (true);
			});

			deleteButton = new StringElement ("Delete".t (), delegate {
				this.DeleteNote(note);
				this.NavigationController.PopToRootViewController (true);
			});


			titleElement = new EntryElement ("NoteTitle".t(), "Title", note.NoteTitle);
			dateElement = new DateElement ("NoteDate".t(), note.NoteDate);

			// Quick little patch to allow MT.D DateElements to work with iOS 7
			if (MonoTouch.UIKit.UIDevice.CurrentDevice.CheckSystemVersion (7, 0)) {
				dateElement.BackgroundColor = UIColor.White;
			}

			textElement = new SimpleMultilineEntryElement ("NoteText".t(), note.NoteText) {Editable = true};

			string Caption = note.NoteId == 0 ? "New".t() : "EditNote".t();

			Section EditButtons = null;

			if (note.NoteId > 0) {
				EditButtons = new Section () {
					saveButton,
					deleteButton
				};
			} else {
				EditButtons = new Section () {
					saveButton
				};
			}

			var root = new RootElement(Caption) {
				new Section() {
					titleElement,
					dateElement,
					textElement
				},
				EditButtons
			};

			dvcDetails = new DialogViewController(root, true);

			this.NavigationController.PushViewController(dvcDetails, true);
		}

		private void CreateFakeData()
		{
			if (notes.Count == 0) {
				notes.Add (new Note () { NoteDate = DateTime.Now, NoteId = 0, NoteTitle = "New Note 1" });
				notes.Add (new Note () { NoteDate = DateTime.Now, NoteId = 0, NoteTitle = "New Note 2" });
				notes.Add (new Note () { NoteDate = DateTime.Now, NoteId = 0, NoteTitle = "New Note 3" });

				notes[0].NoteId = NoteManager.SaveNote (notes [0]);
				notes[1].NoteId = NoteManager.SaveNote (notes [1]);
				notes[2].NoteId = NoteManager.SaveNote (notes [2]);
			}
		}

		public override void ViewDidLoad()
		{
			base.ViewDidLoad();

			View.Frame = UIScreen.MainScreen.Bounds;
			View.BackgroundColor = UIColor.White;
			View.AutoresizingMask = UIViewAutoresizing.FlexibleWidth | UIViewAutoresizing.FlexibleHeight;

			this.NavigationItem.SetRightBarButtonItem(
				new UIBarButtonItem(UIBarButtonSystemItem.Add, (sender, args) =>
			                    {
				CreateMTD(new Note());
			}), true);

			table = new UITableView(new RectangleF(0, 0, View.Frame.Width, View.Frame.Height));
			table.AutoresizingMask = UIViewAutoresizing.All;

			notes = NoteManager.GetNotes().ToList();

			CreateFakeData ();

			Source = new NotesTableSource(notes);
			Source.OnEdit += (sender, e) => {
				CreateMTD(e.note);
			};

			table.Source = Source;

			Add(table);
		}

	}
}

