﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using MonoTouch.Foundation;
using MonoTouch.UIKit;
using notes.Core;

namespace notes.iPhone
{
	public class NoteEventArgs : EventArgs
	{
		public Note note { get; set; }
	}

	public class NotesTableSource : UITableViewSource
	{
		public List<Note> tableitems = new List<Note>();
		protected string cellIdentifier = "NoteTableCell";

		public event EventHandler<NoteEventArgs> OnEdit;

		public NotesTableSource(List<Note> notes)
		{
			tableitems = notes;
		}

		public override int RowsInSection(UITableView tableview, int section)
		{
			return tableitems.Count;
		}

		public override UITableViewCell GetCell(UITableView tableView, NSIndexPath indexPath)
		{
			UITableViewCell cell = tableView.DequeueReusableCell(cellIdentifier);

			if (cell == null)
			{
				cell = new UITableViewCell(UITableViewCellStyle.Subtitle, cellIdentifier);
				cell.Accessory = UITableViewCellAccessory.DetailDisclosureButton;
			}

			cell.TextLabel.Text = tableitems[indexPath.Row].NoteTitle;
			cell.DetailTextLabel.Text = tableitems [indexPath.Row].NoteDate.ToShortDateString ();

			return cell;
		}

		public override void CommitEditingStyle(UITableView tableView, UITableViewCellEditingStyle editingStyle, NSIndexPath indexPath)
		{
			if (editingStyle == UITableViewCellEditingStyle.Delete)
			{
				tableitems.RemoveAt(indexPath.Row);
				tableView.DeleteRows(new[] { indexPath }, UITableViewRowAnimation.Fade);
			}
		}

		public override UITableViewCellEditingStyle EditingStyleForRow(UITableView tableView, NSIndexPath indexPath)
		{
			return UITableViewCellEditingStyle.Delete;
		}

		public override bool CanEditRow(UITableView tableView, NSIndexPath indexPath)
		{
			return true;
		}

		public override void AccessoryButtonTapped(UITableView tableView, NSIndexPath indexPath)
		{
			var edit = OnEdit;

			if (edit != null) {
				edit (this, new NoteEventArgs(){note = tableitems [indexPath.Row]});
			}
		}
	}
}
