﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Xml;
using System.Xml.Serialization;
using System.Linq;

namespace notes.Core
{
    public class NoteRepository
    {
        private static List<Note> notes;
        static string storeLocation;

        static NoteRepository()
        {
            // set the db location
            storeLocation = DatabaseFilePath;
            notes = new List<Note>();

            // deserialize XML from file at dbLocation
            ReadXml();
        }

        static void ReadXml()
        {
            if (File.Exists(storeLocation))
            {
                var serializer = new XmlSerializer(typeof(List<Note>));
                using (var stream = new FileStream(storeLocation, FileMode.Open))
                {
                    notes = (List<Note>)serializer.Deserialize(stream);
                }
            }
        }
        static void WriteXml()
        {
            var serializer = new XmlSerializer(typeof(List<Note>));
            using (var writer = new StreamWriter(storeLocation))
            {
                serializer.Serialize(writer, notes);
            }
        }

        public static string DatabaseFilePath
        {
            get
            {
                var storeFilename = "Notes.xml";
#if SILVERLIGHT
				// Windows Phone expects a local path, not absolute
				//var path = sqliteFilename;
                var folder = Windows.Storage.ApplicationData.Current.LocalFolder;
                var path = Path.Combine(folder.Path, storeFilename);
#else

#if __ANDROID__
				// Just use whatever directory SpecialFolder.Personal returns
				string libraryPath = Environment.GetFolderPath(Environment.SpecialFolder.Personal); ;
#else
                // we need to put in /Library/ on iOS5.1 to meet Apple's iCloud terms
                // (they don't want non-user-generated data in Documents)
                string documentsPath = Environment.GetFolderPath(Environment.SpecialFolder.Personal); // Documents folder
                string libraryPath = Path.Combine(documentsPath, "..", "Library"); // Library folder
#endif
                var path = Path.Combine(libraryPath, storeFilename);
#endif
                return path;
            }
        }


        public static Note GetNote(int id)
        {
            for (var t = 0; t < notes.Count; t++)
            {
                if (notes[t].NoteId == id)
                    return notes[t];
            }
            return new Note() { NoteId = id };
        }

        public static IEnumerable<Note> GetNotes()
        {
            return notes;
        }

        public static int SaveNote(Note item)
        {
            var max = 0;
            if (notes.Count > 0)
                max = notes.Max(x => x.NoteId);

            if (item.NoteId == 0)
            {
                item.NoteId = ++max;
                notes.Add(item);
            }
//            else
//            {
//                var i = notes.Find(x => x.NoteId == item.NoteId);
//                i = item; // replaces item in collection with updated value
//            }

            WriteXml();
            return max;
        }

        public static int DeleteNote(int id)
        {
            for (var t = 0; t < notes.Count; t++)
            {
                if (notes[t].NoteId == id)
                {
                    notes.RemoveAt(t);
                    WriteXml();
                    return 1;
                }
            }

            return -1;
        }

    }
}
